Rails.application.routes.draw do
  get "leaderboard/index"
  # Reveal health status on /up that returns 200 if the app boots with no exceptions, otherwise 500.
  # Can be used by load balancers and uptime monitors to verify that the app is live.
  get "up" => "rails/health#show", as: :rails_health_check

  # Defines the root path route ("/")
  root "leaderboard#index"

  # Game
  get "game/:id", to: "game#show"
  get "games", to: "game#index", as: "games", defaults: { format: :html }

  # Only take JSON for POST to game
  resources :game, only: [ :create ], defaults: { format: :json }

  # Player
  resources :player, only: [ :show ]

  # Leaderboard
  get "leaderboard", to: "leaderboard#index", as: "leaderboard", defaults: { format: :html }

  # Discord
  match "discord" => redirect("https://discord.gg/hQShdPMy7p"), via: [ :get ]

  # Bot
  get "bot/leaderboard" => "bot#leaderboard"
  get "bot/lords" => "bot#lords"
  get "bot/weekly" => "bot#weekly"

  # Admin
  get "admin", to: "admin#index"
  post "admin/set_alt", to: "admin#set_alt"
  post "admin/clear_alt", to: "admin#clear_alt"
  get "admin/login", to: "admin#login"
  post "admin/login_submit", to: "admin#login_submit"
  get "admin/destroy", to: "admin#destroy"
  post "admin/set_lootban", to: "admin#set_lootban"
  post "admin/delete_lootban", to: "admin#clear_lootban"

  # Loot
  resources :loot, only: [ :create ], defaults: { format: :json }
  get "loot", to: "loot#index"
  get "loot/list", to: "loot#list"
end
